BigOutlineButton class

Inheritance

Constructors

BigOutlineButton({Key? key, String? title, Color? lineColor, Color? textColor, bool isEnable = true, double? width, VoidCallback? onTap, ButtonConfig? themeData})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEnable → bool
是否可用,默认为true。false为不可用:置灰、不可点击。
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineColor → Color?
边框的颜色
final
onTap → VoidCallback?
点击回调
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color?
显示的文案的颜色
final
themeData → ButtonConfig?
final
title → String?
按钮显示文案,默认'确认'
final
width → double?
默认父布局可用空间
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited